@@ -126,9 +126,7 @@ namespace bpp
       return *this;
     }
 
-#ifndef NO_VIRTUAL_COV
     virtual AbstractAlphabet* clone() const = 0;
-#endif
 
     virtual ~AbstractAlphabet()
     {
@@ -156,6 +154,7 @@ namespace bpp
     std::string getGeneric(const std::vector<std::string>& states) const throw (AlphabetException);
     const std::vector<int>& getSupportedInts() const;
     const std::vector<std::string>& getSupportedChars() const;
+    const std::vector<std::string> & getResolvedChars() const;
     int getGapCharacterCode() const { return -1; }
     bool isGap(int state) const { return state == -1; }
     bool isGap(const std::string& state) const { return charToInt(state) == -1; }
