@@ -88,7 +88,7 @@ public:
    * @param pAlpha The Pointer to the Alphabet to be used.
    * @param num the length of the words.
    */
-  WordAlphabet(const Alphabet* pAlpha, unsigned int num);
+  WordAlphabet(const Alphabet* pAlpha, size_t num);
 
   WordAlphabet(const WordAlphabet& bia) : AbstractAlphabet(bia), vAbsAlph_(bia.vAbsAlph_) {}
 
@@ -215,6 +215,18 @@ public:
     return vAbsAlph_[n];
   }
 
+  /**
+   * @brief Get the int code for a word given the int code of the underlying positions.
+   *
+   * The int code of each position must match the corresponding alphabet specified at this position.
+   * @param seq description for all the positions as a Sequence object.
+   * @param pos the start position to match in the vector.
+   * @return The int code of the word.
+   * @throw IndexOutOfBoundsException In case of wrong position.
+   */
+  virtual int getWord(const Sequence& seq, size_t pos = 0) const throw (IndexOutOfBoundsException);
+
+
   /**
    * @brief Get the int code for a word given the int code of the underlying positions.
    *
