@@ -40,6 +40,7 @@
 
 #include "SequenceApplicationTools.h"
 #include "../Alphabet/BinaryAlphabet.h"
+#include "../Alphabet/LexicalAlphabet.h"
 #include "../Alphabet/DefaultAlphabet.h"
 #include "../Alphabet/CodonAlphabet.h"
 #include "../Alphabet/AlphabetTools.h"
@@ -78,36 +79,78 @@ Alphabet* SequenceApplicationTools::getAlphabet(
   bool allowGeneric,
   int warn) throw (Exception)
 {
-  Alphabet* chars;
+  Alphabet* chars = 0;
+  
   string alphtt = ApplicationTools::getStringParameter("alphabet", params, "DNA", suffix, suffixIsOptional, warn);
 
-  string alphabet = "";
   map<string, string> args;
-  int flag = 0;
 
+  string alphabet;
   KeyvalTools::parseProcedure(alphtt, alphabet, args);
-  unsigned int lg = 1;
 
   if (alphabet == "Word")
   {
-    if (args.find("length") == args.end())
-      throw Exception("Missing length parameter for Word alphabet");
-    lg = TextTools::to<unsigned int>(args["length"]);
-    if (args.find("letter") == args.end())
-      throw Exception("Missing letter alphabet for Word alphabet");
-    alphabet = args["letter"];
-    flag = 1;
+    if (args.find("letter") != args.end())
+    {
+      args["alphabet"]=args["letter"];
+      
+      Alphabet* inAlphabet = SequenceApplicationTools::getAlphabet(args, suffix, suffixIsOptional, false, allowGeneric, warn+1);
+      
+      if (args.find("length") == args.end())
+        throw Exception("Missing length parameter for Word alphabet");
+
+      size_t lg = TextTools::to<unsigned int>(args["length"]);
+
+      chars = new WordAlphabet(inAlphabet, lg);
+    }
+    else
+    {
+      size_t indAlph = 1;
+      vector<const Alphabet*> vAlph;
+
+      while (args.find("alphabet" + TextTools::toString(indAlph)) != args.end())
+      {
+        map<string,string> args2;
+        args2["alphabet"]=args["alphabet" + TextTools::toString(indAlph)];
+
+        vAlph.push_back(SequenceApplicationTools::getAlphabet(args2, suffix, suffixIsOptional, verbose, allowGeneric, warn));
+        indAlph++;
+      }
+
+      if (vAlph.size() == 0)
+        throw Exception("SequenceApplicationTools::getAlphabet. At least one alphabet  is compulsory for Word alphabet");
+
+      chars = new WordAlphabet(vAlph);
+    }
   }
   else if (alphabet == "RNY")
   {
     if (args.find("letter") == args.end())
       throw Exception("Missing letter alphabet for RNY alphabet");
-    alphabet = args["letter"];
-    flag = 2;
-  }
 
-  if (alphabet == "Binary")
+    args["alphabet"]=args["letter"];
+      
+    Alphabet* inAlphabet = SequenceApplicationTools::getAlphabet(args, suffix, suffixIsOptional, verbose, allowGeneric, warn);
+
+    if (AlphabetTools::isNucleicAlphabet(inAlphabet))
+    {
+      chars = new RNY(*(dynamic_cast<NucleicAlphabet*>(chars)));
+      alphabet = "RNY(" + alphabet + ")";
+    }
+    else
+      throw Exception("RNY needs a Nucleic Alphabet, instead of " + args["letter"]);
+  }
+  else if (alphabet == "Binary")
     chars = new BinaryAlphabet();
+  else if (alphabet == "Lexicon")
+  {
+    vector<string> vWord = ApplicationTools::getVectorParameter<string>("words", args, ',', "()");
+
+    if (vWord.size()==0)
+      throw Exception("SequenceApplicationTools::getAlphabet. 'words' list is missing or empty for Lexicon alphabet");
+    
+    chars = new LexicalAlphabet(vWord);
+  }
   else if (alphabet == "DNA")
   {
     bool mark = ApplicationTools::getBooleanParameter("bangAsGap", args, false, "", true, warn + 1);
@@ -150,35 +193,12 @@ Alphabet* SequenceApplicationTools::getAlphabet(
 
 
     chars = new CodonAlphabet(pnalph);
-    alphabet = alphabet + "(" + alphn + ")";
   }
   else
     throw Exception("Alphabet not known: " + alphabet);
 
-  if (flag == 1)
-  {
-    chars = new WordAlphabet(chars, lg);
-    string al = " ";
-    for (unsigned i = 0; i < lg; i++)
-    {
-      al += alphabet + " ";
-    }
-    alphabet = "Word(" + al + ")";
-  }
-  else if (flag == 2)
-  {
-    if (AlphabetTools::isNucleicAlphabet(chars))
-    {
-      chars = new RNY(*(dynamic_cast<NucleicAlphabet*>(chars)));
-      alphabet = "RNY(" + alphabet + ")";
-    }
-    else
-      throw Exception("RNY needs a Nucleic Alphabet, instead of " + alphabet);
-  }
-
-
   if (verbose)
-    ApplicationTools::displayResult("Alphabet type ", alphabet);
+    ApplicationTools::displayResult("Alphabet type ", chars->getAlphabetType());
   return chars;
 }
 
@@ -236,7 +256,7 @@ SequenceContainer* SequenceApplicationTools::getSequenceContainer(
   string sequenceFilePath = ApplicationTools::getAFilePath("input.sequence.file", params, true, true, suffix, suffixIsOptional, "none", warn);
   string sequenceFormat = ApplicationTools::getStringParameter("input.sequence.format", params, "Fasta()", suffix, suffixIsOptional, warn);
   BppOSequenceReaderFormat bppoReader(warn);
-  auto_ptr<ISequence> iSeq(bppoReader.read(sequenceFormat));
+  unique_ptr<ISequence> iSeq(bppoReader.read(sequenceFormat));
   if (verbose)
   {
     ApplicationTools::displayResult("Sequence file " + suffix, sequenceFilePath);
@@ -247,8 +267,95 @@ SequenceContainer* SequenceApplicationTools::getSequenceContainer(
   return sequences;
 }
 
+
 /******************************************************************************/
 
+map<size_t, SiteContainer*> SequenceApplicationTools::getSiteContainers(
+  const Alphabet* alpha,
+  map<string, string>& params,
+  const string& prefix,
+  const string& suffix,
+  bool suffixIsOptional,
+  bool verbose,
+  int warn)
+{
+  vector<string> vContName = ApplicationTools::matchingParameters(prefix + "data*", params);
+
+  map<size_t, SiteContainer*> mCont;
+
+  for (size_t nT = 0; nT < vContName.size(); nT++)
+  {
+    size_t poseq = vContName[nT].find("=");
+    size_t num = 0;
+    size_t len = (prefix + "data").size();
+
+    string suff = vContName[nT].substr(len, poseq - len);
+
+    if (TextTools::isDecimalInteger(suff, '$'))
+      num = TextTools::to<size_t>(suff);
+    else
+      num = 1;
+
+    string contDesc = ApplicationTools::getStringParameter(vContName[nT], params, "", suffix, suffixIsOptional);
+
+    string contName;
+
+    map<string, string> args;
+
+    KeyvalTools::parseProcedure(contDesc, contName, args);
+
+    map<string, string> args2;
+
+    if (contName == "alignment")
+    {
+      string format;
+
+      if (args.find("file") != args.end())
+        args2["input.sequence.file"] = args["file"];
+      else
+        args2["input.sequence.file"] = "";
+
+      if (args.find("format") != args.end())
+        args2["input.sequence.format"] = args["format"];
+
+      if (args.find("selection") != args.end())
+        args2["input.site.selection"] = args["selection"];
+
+      if (args.find("sites_to_use") != args.end())
+        args2["input.sequence.sites_to_use"] = args["sites_to_use"];
+
+      if (args.find("max_gap_allowed") != args.end())
+        args2["input.sequence.max_gap_allowed"] = args["max_gap_allowed"];
+
+      if (args.find("max_unresolved_allowed") != args.end())
+        args2["input.sequence.max_unresolved_allowed"] = args["max_unresolved_allowed"];
+
+      if (args.find("remove_stop_codons") != args.end())
+        args2["input.sequence.remove_stop_codons"] = args["remove_stop_codons"];
+
+      args2["genetic_code"] = ApplicationTools::getStringParameter("genetic_code", params, "", "", true, (dynamic_cast<const CodonAlphabet*>(alpha)?0:1));
+
+      ApplicationTools::displayMessage("");
+      ApplicationTools::displayMessage("Data " + TextTools::toString(num));
+
+      VectorSiteContainer* vsC = getSiteContainer(alpha, args2, "", true, verbose, warn);
+
+      VectorSiteContainer* vsC2 = getSitesToAnalyse(*vsC, args2, "", true, false);
+
+      delete vsC;
+
+      if (mCont.find(num) != mCont.end())
+      {
+        ApplicationTools::displayWarning("Alignment " + TextTools::toString(num) + " already assigned, replaced by new one.");
+        delete mCont[num];
+      }
+      mCont[num] = vsC2;
+    }
+  }
+
+  return mCont;
+}
+
 VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   const Alphabet* alpha,
   map<string, string>& params,
@@ -260,7 +367,7 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   string sequenceFilePath = ApplicationTools::getAFilePath("input.sequence.file", params, true, true, suffix, suffixIsOptional, "none", warn);
   string sequenceFormat = ApplicationTools::getStringParameter("input.sequence.format", params, "Fasta()", suffix, suffixIsOptional, warn);
   BppOAlignmentReaderFormat bppoReader(warn);
-  auto_ptr<IAlignment> iAln(bppoReader.read(sequenceFormat));
+  unique_ptr<IAlignment> iAln(bppoReader.read(sequenceFormat));
   map<string, string> args(bppoReader.getUnparsedArguments());
   if (verbose)
   {
@@ -277,6 +384,7 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   const SequenceContainer* seqCont = iAln->readAlignment(sequenceFilePath, alpha2);
 
   VectorSiteContainer* sites2 = new VectorSiteContainer(*dynamic_cast<const OrderedSequenceContainer*>(seqCont));
+
   delete seqCont;
 
   VectorSiteContainer* sites;
@@ -294,8 +402,6 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   else
     sites = sites2;
 
-
-  
   // Look for site selection:
   if (iAln->getFormatName() == "MASE file")
   {
@@ -326,23 +432,31 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   {
     // getting site set:
     size_t nbSites = sites->getNumberOfSites();
-    
+
     string siteSet = ApplicationTools::getStringParameter("input.site.selection", params, "none", suffix, suffixIsOptional, warn + 1);
 
-    VectorSiteContainer* selectedSites=0;
+    VectorSiteContainer* selectedSites = 0;
     if (siteSet != "none")
     {
       vector<size_t> vSite;
-      try {
-        vector<int> vSite1 = NumCalcApplicationTools::seqFromString(siteSet);
-        for (size_t i = 0; i < vSite1.size(); ++i){
-          int x = (vSite1[i] >= 0 ? vSite1[i] : static_cast<int>(nbSites) + vSite1[i]);
-          if (x >= 0)
-            vSite.push_back(static_cast<size_t>(x-1));
+      try
+      {
+        vector<int> vSite1 = NumCalcApplicationTools::seqFromString(siteSet,",",":");
+        for (size_t i = 0; i < vSite1.size(); ++i)
+        {
+          int x = (vSite1[i] >= 0 ? vSite1[i] : static_cast<int>(nbSites) + vSite1[i]+ 1);
+          if (x<=(int)nbSites)
+          {
+            if (x > 0)
+              vSite.push_back(static_cast<size_t>(x - 1));
+            else
+              throw Exception("SequenceApplicationTools::getSiteContainer(). Incorrect null index: " + TextTools::toString(x));
+          }
           else
-            throw Exception("SequenceApplicationTools::getSiteContainer(). Incorrect negative index: " + TextTools::toString(x));
+            throw Exception("SequenceApplicationTools::getSiteContainer(). Too large index: " + TextTools::toString(x));
         }
         selectedSites = dynamic_cast<VectorSiteContainer*>(SiteContainerTools::getSelectedSites(*sites, vSite));
+        selectedSites->reindexSites();
       }
       catch (Exception& e)
       {
@@ -357,14 +471,18 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
           vSite.resize(n);
           vector<size_t> vPos;
           for (size_t p = 0; p < nbSites; ++p)
+          {
             vPos.push_back(p);
-          
+          }
+
           RandomTools::getSample(vPos, vSite, replace);
 
           selectedSites = dynamic_cast<VectorSiteContainer*>(SiteContainerTools::getSelectedSites(*sites, vSite));
           if (replace)
             selectedSites->reindexSites();
         }
+        else
+          throw Exception("Unknown site selection description: " + siteSet);
       }
 
       if (verbose)
@@ -536,8 +654,9 @@ VectorSiteContainer* SequenceApplicationTools::getSitesToAnalyse(
     if (option == "yes")
     {
       string codeDesc = ApplicationTools::getStringParameter("genetic_code", params, "Standard", "", true, warn);
-      auto_ptr<GeneticCode> gCode(getGeneticCode(ca->getNucleicAlphabet(), codeDesc));
-      sitesToAnalyse2 = dynamic_cast<VectorSiteContainer*>(SiteContainerTools::removeStopCodonSites(*sitesToAnalyse, *gCode));
+      unique_ptr<GeneticCode> gCode(getGeneticCode(ca->getNucleicAlphabet(), codeDesc));
+      const SiteContainer* constSites = sitesToAnalyse;
+      sitesToAnalyse2 = dynamic_cast<VectorSiteContainer*>(SiteContainerTools::removeStopCodonSites(*constSites, *gCode));
       delete sitesToAnalyse;
     }
     else
@@ -561,7 +680,7 @@ void SequenceApplicationTools::writeSequenceFile(
   string sequenceFilePath = ApplicationTools::getAFilePath("output.sequence.file", params, true, false, suffix, false, "none", warn);
   string sequenceFormat   = ApplicationTools::getStringParameter("output.sequence.format", params, "Fasta", suffix, false, warn);
   BppOSequenceWriterFormat bppoWriter(warn);
-  auto_ptr<OSequence> oSeq(bppoWriter.read(sequenceFormat));
+  unique_ptr<OSequence> oSeq(bppoWriter.read(sequenceFormat));
   if (verbose)
   {
     ApplicationTools::displayResult("Output sequence file " + suffix, sequenceFilePath);
@@ -584,7 +703,7 @@ void SequenceApplicationTools::writeAlignmentFile(
   string sequenceFilePath = ApplicationTools::getAFilePath("output.sequence.file", params, true, false, suffix, false, "none", warn);
   string sequenceFormat   = ApplicationTools::getStringParameter("output.sequence.format", params, "Fasta", suffix, false, warn);
   BppOAlignmentWriterFormat bppoWriter(warn);
-  auto_ptr<OAlignment> oAln(bppoWriter.read(sequenceFormat));
+  unique_ptr<OAlignment> oAln(bppoWriter.read(sequenceFormat));
   if (verbose)
   {
     ApplicationTools::displayResult("Output alignment file " + suffix, sequenceFilePath);
@@ -596,4 +715,3 @@ void SequenceApplicationTools::writeAlignmentFile(
 }
 
 /******************************************************************************/
-
