@@ -111,8 +111,10 @@ class SequenceContainerTools
     template<class ContFrom, class ContTo, class Seq>
     static void convertContainer(const ContFrom& input, ContTo& output) {
       for (size_t i = 0; i < input.getNumberOfSequences(); ++i) {
-        std::auto_ptr<Seq> seq(new Seq(input.getSequence(i)));
-        output.addSequence(*seq);
+        std::unique_ptr<Seq> seq(new Seq(input.getSequence(i)));
+        output.addSequence(*seq, false); //We do not check sequence name here.
+                                         //If names were duplicated in the original container,
+                                         //they will also be in the converted one.
       }
     }
 
@@ -256,7 +258,7 @@ class SequenceContainerTools
       for (size_t i = 0; i < seqNames.size(); i++)
       {
         BasicSequence tmp = seqCont1.getSequence(seqNames[i]);
-        tmp.append(seqCont2.getContent(seqNames[i]));
+        tmp.append(seqCont2.getSequence(seqNames[i]));
         outputCont.addSequence(tmp, false);
       }
     }
