@@ -512,6 +512,18 @@ Vint VectorSiteContainer::getSitePositions() const
   return positions;
 }
 
+void VectorSiteContainer::setSitePositions(Vint vPositions)
+{
+  if (vPositions.size() != sites_.size())
+    throw BadSizeException("VectorSiteContainer::setSitePositions bad size of positions vector", vPositions.size(), sites_.size());
+  
+  size_t pos = 0; // first position is 1.
+  for (vector<Site*>::iterator i = sites_.begin(); i < sites_.end(); i++)
+  {
+    (*i)->setPosition(vPositions[pos++]);
+  }
+}
+
 /******************************************************************************/
 
 const Sequence& VectorSiteContainer::getSequence(size_t i) const throw (IndexOutOfBoundsException)
@@ -524,7 +536,7 @@ const Sequence& VectorSiteContainer::getSequence(size_t i) const throw (IndexOut
   vector<int> sequence(n);
   for (size_t j = 0; j < n; j++)
   {
-    sequence[j] = sites_[j]->getContent()[i];
+    sequence[j] = (*sites_[j])[i];
   }
   if (sequences_[i])
     delete sequences_[i];
