@@ -124,12 +124,7 @@ namespace bpp {
        * @name The Clonable interface
        * @{
        */
-#ifdef NO_VIRTUAL_COV
-      Clonable*
-#else
-      SequenceQuality*
-#endif
-      clone() const { return new SequenceQuality(*this); }
+      SequenceQuality* clone() const { return new SequenceQuality(*this); }
       /** @} */
 
     public:
@@ -522,12 +517,7 @@ namespace bpp {
        * @name The Clonable interface
        * @{
        */
-#ifdef NO_VIRTUAL_COV
-      Clonable*
-#else
-      SequenceWithQuality*
-#endif
-      clone() const { return new SequenceWithQuality(*this); }
+      SequenceWithQuality* clone() const { return new SequenceWithQuality(*this); }
       /** @} */
 
       /**
@@ -590,11 +580,7 @@ namespace bpp {
         return qualScores_->getScores();
       }
 
-      void append(const std::vector<int>& content)
-        throw (BadIntException)
-      {
-        SequenceWithAnnotation::append(content);
-      }
+      using SequenceWithAnnotation::append;
 
       /**
        * @brief Append content with quality
@@ -607,7 +593,7 @@ namespace bpp {
        * @throw DimensionException if qualities does not have the same size as
        * content
        */
-      void append(
+      virtual void append(
           const std::vector<int>& content,
           const std::vector<int>& qualities)
         throw (BadIntException, DimensionException)
@@ -620,12 +606,6 @@ namespace bpp {
         qualScores_->setScores(pos, qualities);
       }
 
-      void append(const std::vector<std::string>& content)
-        throw (BadCharException)
-      {
-        SequenceWithAnnotation::append(content);
-      }
-
       /**
        * @brief Append content with quality
        *
@@ -637,7 +617,7 @@ namespace bpp {
        * @throw DimensionException if qualities does not have the same size as
        * content
        */
-      void append(
+      virtual void append(
           const std::vector<std::string>& content,
           const std::vector<int>& qualities)
         throw (BadCharException, DimensionException)
@@ -650,12 +630,6 @@ namespace bpp {
         qualScores_->setScores(pos, qualities);
       }
 
-      void append(const std::string& content)
-        throw (BadCharException)
-      {
-        SequenceWithAnnotation::append(content);
-      }
-
       /**
        * @brief Append content with quality
        *
@@ -667,7 +641,7 @@ namespace bpp {
        * @throw DimensionException if qualities does not have the same size as
        * content
        */
-      void append(
+      virtual void append(
           const std::string& content,
           const std::vector<int>& qualities)
         throw (BadCharException, DimensionException)
