@@ -67,9 +67,7 @@ namespace bpp
      *
      * @{
      */
-#ifndef NO_VIRTUAL_COV
     SymbolList* clone() const = 0;
-#endif
     /** @} */
 
     // Class destructor
@@ -98,13 +96,6 @@ namespace bpp
      * @{
      */
 
-    /**
-     * @brief Get the whole content of the list as a vector of int.
-     *
-     * @return A reference to the content of the list.
-     */
-    virtual const std::vector<int>& getContent() const = 0;
-
     /**
      * @brief Set the whole content of the list.
      *
@@ -332,25 +323,18 @@ namespace bpp
      *
      * @{
      */
-#ifdef NO_VIRTUAL_COV
-    Clonable*
-#else
-    BasicSymbolList*
-#endif
-    clone() const { return new BasicSymbolList(* this); }
+    BasicSymbolList* clone() const { return new BasicSymbolList(* this); }
     /** @} */
 
     // Class destructor
     virtual ~BasicSymbolList() {}
-
+    
   public:
 
     virtual const Alphabet* getAlphabet() const { return alphabet_; }
 
     virtual size_t size() const { return static_cast<size_t>(content_.size()); }
 
-    virtual const std::vector<int>& getContent() const { return content_; }
-		
     virtual void setContent(const std::vector<int>& list) throw (BadIntException);
 
     virtual void setContent(const std::vector<std::string>& list) throw (BadCharException);
@@ -467,9 +451,7 @@ namespace bpp
   public:
     virtual ~SymbolListListener() {}
 
-#ifndef NO_VIRTUAL_COV
     virtual SymbolListListener* clone() const = 0;
-#endif
 
   public:
     virtual bool isRemovable() const = 0;
@@ -576,12 +558,7 @@ namespace bpp
      *
      * @{
      */
-#ifdef NO_VIRTUAL_COV
-    Clonable*
-#else
-    EdSymbolList*
-#endif
-    clone() const { return new EdSymbolList(* this); }
+    EdSymbolList* clone() const { return new EdSymbolList(* this); }
     /** @} */
 
     // Class destructor
